import { Layout, Dropdown, Menu, Modal, Input, Form, Space, Button } from 'antd';
import { withRouter } from 'react-router'
import { useState, useEffect } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { panesNow } from '@reducers/tabPanes.js';
import utils from '@utils/index';
import logo from '@images/logo.png';
import msg from '@images/msg.png';
import me from '@images/me.png';
import down from '@images/down.png';
import './index.less'
import { message } from "antd/lib/index";
import { setSys, setUser } from '@reducers/userInfo.js';
import apiObj from '@api/index';

const { post, api, xPost } = apiObj;
const propTypes = {

}
const defaultProps = {};
const { Header } = Layout;
const { getTimeDetail } = utils;
function AHeader({ history, hideName }) {
    const dispatch = useDispatch();
    const [form] = Form.useForm();
    const [dateTime, setDateTime] = useState('');
    const [formData, setFormData] = useState(null);
    const [visible, setVisible] = useState(false);
    const { user, sysName } = useSelector((state) => {
        return state.userInfo;
    });
    //退出
    function loginOut() {
        localStorage.removeItem("token");
        localStorage.removeItem("systemId");
        localStorage.removeItem("hospitalId");
        dispatch(panesNow([]));
        history.push('/login');
    }
    //获取组织列表
    function getOrgList() {
        xPost(api.getUserHospitals).then((res) => {
            if (res.data.code === 200) {
                const data = res.data.data;
                const { userInfo, software } = data;
                const sysId = localStorage.getItem("systemId");
                const hisId = localStorage.getItem("hospitalId");
                const sys = software.find((it) => {
                    return +it.id === +sysId
                });
                dispatch(setUser(userInfo));
                sys && dispatch(setSys({ sysId, sysName: sys.name, hisId }));
            } else {
                message.warning(res.data.msg || '获取医院列表失败');
            }
        })
    }
    //修改密码
    function changePsd() {
        setVisible(true)
    }
    //时间
    let interVal;
    function countTime() {
        interVal = setInterval(() => {
            setDateTime(getTimeDetail())
        }, 1000);
    }
    function cancel() {
        setVisible(false)
        form.resetFields();
    }
    const onFinish = values => {
        const params = values
        post(api.midifyPassword, params).then((res) => {
            if (res.data.code === 200) {

            }
        })
    }
    useEffect(() => {
        countTime();
        if (!user.name) {
            getOrgList();
        }
        return function clearUp() {
            clearInterval(interVal)
        }
    }, []);
    const menu = (
        <Menu>
            <Menu.Item key="0">
                <span className='changePsd' onClick={changePsd}>修改密码</span>
            </Menu.Item>
            <Menu.Divider />
            <Menu.Item key="3" onClick={loginOut}>退出</Menu.Item>
        </Menu>
    );
    return (
        <Header className='page-header'>
            <img className='logo' src={logo} alt="" />
            {hideName ? '' : <><span className='break-line'>|</span>
                <span className='sys-name'>{sysName}</span></>}
            <div className='infos'>
                <span className='time'>{dateTime}</span>
                <span className='break-line'>|</span>
                {/*<img className='msg-icon' src={msg} alt="未读消息"/>*/}
                <div className="user">
                    <Dropdown overlay={menu} trigger={['click']}>
                        <span className="ant-dropdown-link" onClick={e => e.preventDefault()}>
                            <img className='user-icon' src={me} alt="用户头像" />
                            <i className='user-name'>{user.name}</i>
                            <img src={down} alt="" />
                        </span>
                    </Dropdown>
                </div>
            </div>
            {visible ?
                <Modal
                    title='修改密码'
                    okText='确定'
                    cancelText='取消'
                    width={'40%'}
                    visible={visible}
                    onCancel={cancel}
                    footer={null}
                    forceRender={true}
                    centered={true}
                >
                    <Form
                        labelCol={{ span: 6 }}
                        wrapperCol={{ span: 16 }}
                        form={form}
                        name="register"
                        onFinish={onFinish}
                    >

                        <Form.Item
                            name="password"
                            label="原密码"
                            required
                        >
                            <Input.Password placeholder="8-12位大小写字母、数字、特殊字符" />
                        </Form.Item>
                        <Form.Item
                            name="modifyPassword"
                            label="新密码"
                            dependencies={['password']}
                            rules={[
                                {
                                    required: true,
                                    message: '8-12位大小写字母、数字、特殊字符',
                                },
                                ({ getFieldValue }) => ({
                                    validator(_, value) {
                                        const passwordReg = /^(?=.*?[a-z])(?=.*?[A-Z])(?=.*?\d)(?=.*?[#@*&.]).*$/;
                                        if (!value || getFieldValue('password') === value) {
                                            return Promise.reject(new Error('新密码不能于原密码相同'));
                                        }
                                        if (!passwordReg.test(value)) {
                                            return Promise.reject(new Error('密码必须同时包含大写字母、小写字母和数字'));
                                        }
                                        if (value.length < 8 || value.length > 12) {
                                            return Promise.reject(new Error('密码长度8-12位'));
                                        }
                                    },
                                }),
                            ]}
                        >
                            <Input.Password placeholder="8-12位大小写字母、数字、特殊字符" />
                        </Form.Item>
                        <Form.Item
                            name="againnewpassword"
                            label="确认新密码"
                            dependencies={['password']}
                            rules={[
                                {
                                    required: true,
                                    message: '8-12位大小写字母、数字、特殊字符',
                                },
                                ({ getFieldValue }) => ({
                                    validator(_, value) {
                                        if (!value || getFieldValue('modifyPassword') === value) {
                                            return Promise.resolve();
                                        }
                                        return Promise.reject(new Error('两次密码不一致,请确认密码'));
                                    },
                                }),
                            ]}
                        >
                            <Input.Password placeholder="8-12位大小写字母、数字、特殊字符" />
                        </Form.Item>
                        <Form.Item wrapperCol={{ offset: 8, span: 16 }}>
                            <Space size="middle">
                                <Button htmlType="button" onClick={e => cancel()}>
                                    取消
                                </Button>
                                <Button type="primary" htmlType="submit">
                                    保存
                                </Button>
                            </Space>
                        </Form.Item>
                    </Form>
                </Modal>
                : ''}
        </Header>

    )
}

AHeader.propTypes = propTypes;
AHeader.defaultProps = defaultProps;
export default withRouter(AHeader);